#
# spec file for package orthos2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           orthos2
Version:        1.3.51+git.127edfa
Release:        2.3
Summary:        Machine administration
URL:            https://github.com/openSUSE/orthos2

Group:          Productivity/Networking/Boot/Servers
%{?systemd_ordering}

License:        GPL-2.0-or-later
Source:         orthos2-%{version}.tar.gz
%if 0%{?suse_version}
Source1:        orthos2.rpmlintrc
%endif
Source2:        system-user-orthos.conf

BuildArch:      noarch

BuildRequires:  fdupes
BuildRequires:  systemd-rpm-macros
# For /etc/nginx{,/conf.d} creation
BuildRequires:  nginx
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires(post): sudo
%if 0%{?suse_version}
BuildRequires:  python-rpm-macros
%endif
BuildRequires:  sysuser-tools
%sysusers_requires

# Finds python dependencies based on egg info generated by setup.py
# Theoretically distro independent and should work this way, but has
# quite some pitfalls. Only works after SLE 15 SP2, due to build service
# restrictions (be careful, there they messed it up and
# python_enable_dependency_generator macro is defined, but does not do
# anything. This check still also needs to explicitly check for SLE 15 SP2...
%if 0%{?sle_version} <= 150300
%undefine python_enable_dependency_generator
%undefine python_disable_dependency_generator
%endif
%{?python_enable_dependency_generator}
%if ! (%{defined python_enable_dependency_generator} || %{defined python_disable_dependency_generator})
Requires:       python3-Django >= 3.2
Requires:       python3-django-auth-ldap
Requires:       python3-django-extensions
Requires:       python3-djangorestframework
Requires:       python3-ldap
Requires:       python3-netaddr
Requires:       python3-paramiko
Requires:       python3-psycopg2
Requires:       python3-validators
%endif
# Needed to install /etc/logrotate.d/orthos2
Requires:       python3-Django >= 3.2
Requires:       /sbin/service
Requires:       ansible
Requires:       logrotate
Requires:       nginx
Requires:       uwsgi
Requires:       uwsgi-python3
Requires:       user(orthos)
Requires:       group(orthos)

Provides:       orthos2-%{version}-%{release}

%description
Orthos is the machine administration tool of the development network at SUSE. It is used for following tasks:

    getting the state of the machine
    overview about the hardware
    overview about the installed software (installations)
    reservation of the machines
    generating the DHCP configuration (via Cobbler)
    reboot the machines remotely
    managing remote (serial) consoles

%package docs
Summary:        HTML documentation for orthos2
BuildRequires:  python3-Sphinx
BuildRequires:  python3-django >= 3.2
BuildRequires:  python3-django-auth-ldap
BuildRequires:  python3-django-extensions
BuildRequires:  python3-djangorestframework
BuildRequires:  python3-ldap
BuildRequires:  python3-netaddr
BuildRequires:  python3-paramiko
BuildRequires:  python3-sphinx_rtd_theme
BuildRequires:  python3-validators


%package -n system-user-orthos
Summary:        Orthos user and group
Group:          System
Requires(pre):  pwdutils
Provides:       group(orthos)
Provides:       user(orthos)
BuildArch:      noarch

%description -n system-user-orthos
Orthos user and group required by orthos2 package


%define orthos_web_docs /srv/www/orthos2/docs

%description docs
HTML documentation that can be put into a web servers htdocs directory for publishing.

%prep
%setup

%build
%sysusers_generate_pre %{SOURCE2} orthos system-user-orthos.conf
%py3_build
cd docs
make html

%install
install -D -m 0644 %{SOURCE2} %{buildroot}%{_sysusersdir}/system-user-orthos.conf
%py3_install

# docs
mkdir -p %{buildroot}%{orthos_web_docs}

# client is built via separate spec file to reduce build dependencies
rm %{buildroot}/usr/bin/orthos2

cp -r docs/_build/html/* %{buildroot}%{orthos_web_docs}
%fdupes %{buildroot}/%{orthos_web_docs}

#systemd
ln -sr %{buildroot}%{python3_sitelib}/orthos2 %{buildroot}/usr/lib/orthos2/orthos2

cp -r ansible %{buildroot}/usr/lib/orthos2/ansible

%pre -n system-user-orthos -f orthos.pre

%pre
%service_add_pre orthos2.service orthos2_taskmanager.service orthos2.socket orthos2_debug.service

%post
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf
%service_add_post orthos2.service orthos2_taskmanager.service orthos2.socket orthos2_debug.service
echo "no sudo available..... and no i will not think of workaround for this for obs..."
echo "run orthos-admin migrate"
echo "run orthos-admin collectstatic --noinput"

%preun
%service_del_preun  orthos2.service orthos2_taskmanager.service orthos2.socket orthos2_debug.service

%postun
%service_del_postun  orthos2.service orthos2_taskmanager.service orthos2.socket orthos2_debug.service

%files
%{python3_sitelib}/orthos2-*
%{_unitdir}/orthos2_taskmanager.service
%{_unitdir}/orthos2.service
%{_unitdir}/orthos2_debug.service
%{_unitdir}/orthos2.socket
%{_tmpfilesdir}/orthos2.conf
%dir %{python3_sitelib}/orthos2/
%{python3_sitelib}/orthos2/*
%dir %{_sysconfdir}/orthos2
%config %{_sysconfdir}/orthos2/orthos2.ini
%config %{_sysconfdir}/orthos2/settings
%config %{_sysconfdir}/logrotate.d/orthos2
%config(noreplace) %{_sysconfdir}/nginx/conf.d/orthos2_nginx.conf
%dir /usr/lib/orthos2
%dir /usr/lib/orthos2/scripts
%dir /usr/share/orthos2
%dir /usr/share/orthos2/fixtures
/usr/share/orthos2/fixtures/*
/usr/lib/orthos2/*
%attr(755,orthos,orthos) %{_bindir}/orthos-admin
%attr(755,orthos,orthos) %dir /srv/www/orthos2
%ghost %dir /run/%{name}
%ghost %dir /run/%{name}/tmp
%ghost %dir /run/%{name}/ansible
%ghost %dir /run/%{name}/ansible_lastrun
%ghost %dir /run/%{name}/ansible_archive
%attr(755,orthos,orthos) %dir /var/log/orthos2
%attr(775,orthos,orthos) %dir /var/lib/orthos2
%attr(775,orthos,orthos) %dir /var/lib/orthos2/archiv
%attr(775,orthos,orthos) %dir /var/lib/orthos2/orthos-vm-images
%attr(775,orthos,orthos) %dir /var/lib/orthos2/database
%attr(700,orthos,orthos) %dir /var/lib/orthos2/.ssh

# defattr(fileattr, user, group, dirattr)
# Add whole ansible directory with correct attr for dirs and files
# Always keep this at the end with defattr
#%%defattr(664, orthos, orthos, 775)
#/usr/lib/orthos2/ansible

%files docs
%dir %{orthos_web_docs}
%{orthos_web_docs}/*

%files -n system-user-orthos
%{_sysusersdir}/system-user-orthos.conf

%changelog
* Tue Apr  2 2024 Boris Manojlovic <boris@steki.net>
- fix system-user-orthos.conf remove group gecos as it is not existing
  in specification
* Tue Mar 26 2024 boris@steki.net
- Update to version 1.3.51+git.127edfa:
  * Data: Add fence_agent to display columns
  * Settings: Add default REMOTEPOWER_TYPES
  * Forms: Fixup RemotePowerDeviceAPIForm
  * SPEC: Use autosetup macro
  * Forms: Match KVM as a word and not as a complete type
  * Virt API: Handle missing ServerConfig key
  * Add typing requirements
  * CI: Switch to black profile
  * API: Add correct authentication to BMC add
  * Forms: Add constructor to BMC
  * Docs: Add BMC command for CLI
  * Tests: Splitup file and add multiple ones
  * Fixtures: Add for new test
  * Fixtures: Add virt_api_int to test machine
  * Ingore: Add vscode directory
* Sat Mar 23 2024 boris@steki.net
- Update to version 1.3.29+git.9325baa:
  * Hostnamefinder: Add typing
  * Hostnamefinder: Fix import
  * CI: Execute integration tests
  * Docker: Add test docker-compose
  * Tests: Initial of integration tests
  * CLI: Add specfile
  * CI: Introduce mypy optionally
  * Admin: Fix bug that network switches can't select any architecture
  * Revert "Sconsole: Switch from _cscreen to cscreen user"
  * Sconsole: Switch from _cscreen to cscreen user
  * Docker: Give fixture example
  * Tests: Fixup for multiple django fixtures
  * RTD: Fixup config according to new schema
  * Requirements: Upgrade Django to 4.2 LTS
  * Admin - Display Add/Change page faster
  * Utils: SSH - Add typing annotations
  * Cobbler: Add typing annotations
  * Utils: SSH - Remove manual debug code
  * Remove "makemigrations" from Orthos2 setup
  * Migrations: Initial add
  * SPEC: Remove old symlinks
  * Tests: Fixup machine admin view
  * Misc: Type annotations
  * Signals: Type annotations
  * Models: Type annotation
  * Cobbler: Add type annotation
  * Remotepowerdevice: Fixup model
  * Tests: Fixup login tests
  * Views: Add missing prefix
  * Tests: Fixup Cobbler tests
  * Fix: Machine change form arch system dropdown filter
  * Templates: Fixup untested path
  * Docker: Extend README
  * Use package_data for shipping files
  * SPEC: Fixup unitdir macro usage
  * Data: Models - Fixup get_by_natural_key
  * Tests: Fixup fixture path
  * Tests: Fixup JSON fixtures
  * Docker: Add development container
  * Tests: Fixup mock path
  * Loosen required runtime user account check
  * manage.py: Add executable bit
  * CI: Fixup test workflow inside GH Actions
  * Tests: Add coverage to required devel tools
  * CI: Fixup "django-check" inside GH Actions
  * Fixup pycodestyle linter errors
  * CI: Streamline linter workflow & add django-admin
  * CI: Execute CI in more cases
  * fix: fix that platforms can't be assigned to machines
  * fix: move change_form.html to fix rpm install
  * fix: Add remaining arch system mappings
* Thu May  4 2023 trenn@suse.de
- Update to version 1.2.169+git.a693485:
  * fix: run isort on remaining files
  * fix: Remove unsupported cobbler_server from django admin panel
* Wed May  3 2023 laurin.faeller@suse.com
- Update to version 1.2.166+git.1eaf582:
  * Refactor Domain-CobblerServer relationship to 0:1
  * Fix circular import (#201)
  * IPv4 and IPv6 internal machine object attribute needs updating when moving domain
  * Use get on clean_data dictionary and consistently remove self when using the variable
  * ci: Add isort linter to github actions
  * fix: Run isort for more idiomatic imports
  * Add architecture validation to machine admin panel
  * Implement naive FQDN Change
* Tue Mar 21 2023 laurin.faeller@suse.com
- Update to version 1.2.154+git.40b86d2:
  * Add cobbler stdout message to logger errors
  * Save one call to get_primary_networkinterface()
  * Correctly store and show amount of CPU sockets, cores and threads
  * Fix debug server systemd script
  * Fix django dependency
  * Add documentation to serverconfigs
  * Remove old scripts and introduce /usr/bin/orthos-admin
  * Also enable code checking on pull requests
  * Fix pycodingstyle issues
  * Split pycodingstyle and pylint jobs
  * Fix pylint issues
  * Add pycodingstyle to pylint and rename it to Coding Style
  * Only exclude own network interfaces if the instance already has an primary key
  * Use short hostname in orthos_debug serivce file
  * Merge
  * [pycodingstyle] Fix all...
  * [pycodingstyle] make files pycodingstyle clean
  * [pycodingstyle] orthos2/utils/remote.py clean
  * [pycodestyle] ./orthos2/data/management/commands/dump_db.py clean
  * [pycodestyle] Fix: E301 expected 1 blank line, found 0
  * [pycodestyle] Fix: E302 expected 2 blank lines, found 1
  * [pycodestyle] orthos2/frontend/views.py clean now
  * [pycodestyle] max line length 120
  * [pycodestyle] docs/conf.py clean now
  * [pycodesytle] E114 indentation is not a multiple of 4 (comment)
  * Remove old dump db script
  * Use quotes in python version github action and use v2 action
  * Rename bashrc.sh to server_init.sh and add nginx to orthos user change
  * Add hostname finder utility via script
  * Show id in info <machine> command
  * Fix up dots in button titles
  * Fix E0602: Undefined variable 'InfoCommand' (undefined-variable)
  * Only test python 3.10
  * Fix too early touching of data_serverconfig key
  * Introduce getException in api/commands/base.py
  * Add whole info command path into exception handling
  * Add whole info command path into exception handling
  * Delete secondary MAC adresses if MAC got changed/modified by user
  * Add reworked Django script dump_db
  * Check if_valid() before touching cleaned_data or it may not exist
  * Properly format settings and settings.py
  * Collection of recent fixes
  * Add systemd auto-restart hooks to service files of orthos2 and orthos2_taskmanager
  * Fix memory multiply by 1024
  * Allow machine name into URL
  * Properly implement rpower and platform into query command
  * Check for existing previous BMC before comparing its username
  * Add python3-django BuildRequires
  * Several VM fixes and default value adoptions
  * Enhance orthosrc with pre-defined aliases
  * Revert orthos2_docs_nginx.conf again
  * Add undefined-variable to .pylintrc
  * Fix machine bugs
  * Get image install directory via ServerConfig key
  * Several virtualization fixes
  * Fix not existing attribute usage timezone.ZERO in task RegenerateMotd
* Tue Mar 15 2022 trenn@suse.de
- Update to version 1.2.77+git.f8950eb:
  * Remove shebang from utils/remote.py and add description how to use if for testing
  * Set default serial device fro powerpc to hvc
  * Enhance saver() machine checks to properly update serial console and BMC
  * Do not allow renaming of machines
  * Make use of ssh shell call instead of paramiko lib in machinechecks.py
  * Add remote.py (ssh/scp) to replace paramiko python3 ssh library usage
  * Add remote.py (ssh/scp) to replace paramiko python3 ssh library usage
  * Properly update and also remove in empty case ipv6 and other machine options
  * Properly fix port checking for remote power devices
  * 'W0611' is cryptic: use '# pylint: disable=unused-import' instead
  * Fix wrong import order
  * Fix one bracket too much bug
  * Fix: orthos2.noarch: E: non-executable-script
  * orthos2.noarch: W: tmpfile-not-in-filelist /run/orthos2/ansible_lastrun
  * orthos2.noarch: E: zero-length /usr/lib/python3.8/site-packages/orthos2/utils/models.py
  * Remove not needed lintrc line
  * Signal() does not have providing_args attribute in constructor anymore
  * Use url_has_allowed_host_and_scheme instead of deprecated is_safe_url
  * Convert old django.conf.url import to new django.url
  * Remove wrong or unused translation bits and imports
  * Enhance command line client documentation
  * If no profile to install is provided, just install the assigned profile
  * Introduce autoreinstall machine attribute
  * BMC password field must be a password field.
  * Remote power device username/pass is mandatory, pass must be a password field
  * Provide default/fallback arguement for ServerConfig.by_key similar to dict.get
  * Add URL field to power device to find WebGUI for configuration
  * Add new use_hostname_as_port fence option
  * Add per machine cobbler sync
  * Do not hard code ansible key, this comes from /usr/lib/orthos2/ansible/ansible.cfg
  * Show "All Machines" not only to superuser, but to all users
  * We need a title for the cli manpage
  * Add commandline.rst to doc directory again
  * Remove suse specifics
  * Add example orthosrc
  * Fix regenerate cobbler help -> remove left over
  * Fix indentation introduced by recent ansible lock fix
  * sort serial console types in the cli
  * Always allow to run ansible scan -> fix deadlock
  * enabled the 'bad-indentation' warning, and made according fixes
  * enabled the 'missing-format-argument-key' warning and made according fixes
  * enabled the 'logging not lazy' warning and made according fixes
  * Enabled the superfluous-parens warning, and made according fixes
  * enabled line-to-long warning, and shortened lines accordingly.
  * Enabled wrong-import-order warning and sorted imports accordingly
  * Switched to lazy %%s formating for logging
  * reenabled some pylint warnings
  * fixed a comprehension-escape error
  * Fix HINT: Configure the DEFAULT_AUTO_FIELD setting warning
  * Calm down pylint by removing unused exception variable
  * include SyncCobblerDHCP in tasks init.py
  * Enable and fix unused-variable via pylint
  * Catch Token.DoesNotExist exception at first token generation
  * Add missing sync_dhcp signal
  * Removed unsed imports detected by pylint
  * Create serial console entries for all domains served by a specific console server
  * Add config command to show current connection stats
  * Rework dump script - Use primary keys for only fresh database installation
  * Fix again wrong attr on ansible directory, just use defattr declared one line above
  * Diplay the  screen command in the admin interface
  * Further enhance dump script
  * Natural keys must be tuples
  * Use PositiveSallIntererfield for kernel_device_num
  * Don't delete data for 'Command' sconsoles
* Sat Oct 16 2021 trenn@suse.de
- Update to version 1.0.141+git.58cc722:
  * Add pylint CI workflow
  * Create pylint.yml
  * Add unique natural keys to be able to dump db table without fixed primary key
  * Catch exception in add_machine if hypervisor does not exist
  * client: Properly catch Exception on server side
  * Add missing import in client
  * Tiny fixups
  * Enhance documentation
  * Move user orthosrc file to ~/.config/orthosrc
  * Only show non-administrative machine in free machines list
  * Add not fully finished dump_test_db script and README for Django scripts
  * Enhance ansible scanning
  * Provide ordinary users with "(Re-)Create token" functionality via user preferences
  * Do not allow password change in ldap case
* Fri Oct 15 2021 trenn@suse.de
- Update to version 1.0.141+git.58cc722:
  * Add unique natural keys to be able to dump db table without fixed primary key
  * Catch exception in add_machine if hypervisor does not exist
  * Ask client in add_machine for arch, system and group as ordered lists
  * Make orthos2_debug systemd service file hostname independent
  * Move user orthosrc file to ~/.config/orthosrc
  * Only show non-administrative machine in free machines list
  * Add not fully finished dump_test_db script and README for Django scripts
  * Enhance ansible scanning
  * Add ssh configs to ansible and fix wrong inventory template for multiple hosts
  * Provide ordinary users with "(Re-)Create token" functionality via user preferences
  * Do not allow password change in ldap case
* Mon Oct  4 2021 trenn@suse.de
- Update to version 1.0.90+git.0a104f7:
  * Remove client from spec file
  * Avoid error site if removal of VM on hypervisor was not successful, just log it
  * Correct jira email queue address for report problem button
  * Building docs needs python-Sphinx
  * Remove python-django from build requires, but Require django 3.2 for installation
* Tue Sep 28 2021 trenn@suse.de
- Update to version 1.0.73+git.d0402ef:
  * Fix build
  * Add orthos2_debug (manage.py runserver) as systemd service
* Mon Sep 20 2021 trenn@suse.de
- Update to version 1.0.69+git.73b8b67:
  * Adoption to new cobbler (next-server-v4 and dns-name options)
  * Some ansible fixups
  * also rename type -> stype in the api form
  * Check for BMC existence before accessing
  * console= kernel parameter fixes passed to cobbler
  * Open documentation, bugzilla and download cli links in new browser tab
  * Improved Cobbler sync
  * Refactoring: Use object.get instead of object.filter for nicer error handling
* Fri Sep  3 2021 trenn@suse.de
- Update to version 1.0.56+git.e4af4c1:
  * Add rpmlintrc file to spec Sources
* Thu Sep  2 2021 Thomas Renninger <trenn@suse.de>
- Init changelog
